@@ -2,6 +2,10 @@
 
 //############ Private functions###################
 
+function changeAmpersand(str) {
+    return str.replace("&","%26");
+}
+
 function rilPopulateListModel(list, listmodel) {
     //listmodel.clear()
     var a = JSON.parse(list)["list"];
@@ -55,7 +59,7 @@ function rilDownloadList() {
                     //console.log(o.title);
                     //var status = Storage.getDownloadedStatus(o.url)
                     //if ((status=="Unknown") || (currentArticle=="Not downloaded yet")) {
-                    Storage.saveRilArticle(o.url, o.title, "Not downloaded yet", o.state)
+                    Storage.saveRilArticle(changeAmpersand(o.url), changeAmpersand(o.title), "Not downloaded yet", o.state)
                     //    rilDownloadRilArticle(o.url);
                     //}
                     articleViewer.refreshList();
